#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 spdx
version:              1.0.0.2
visibility:           public
id:                   spdx-1.0.0.2-COGq47VGoHLGd8VVqyuhi
key:                  spdx-1.0.0.2-COGq47VGoHLGd8VVqyuhi
license:              BSD-3-Clause
copyright:            (c) 2015-2018 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/spdx
synopsis:             SPDX license expression language, Extras
description:
    Cabal provides SPDX types. This package provides some extras.

category:             Data
abi:                  03234736f4ffa75280bba7ff8e256e78
exposed:              True
exposed-modules:
    Distribution.SPDX.Extra Distribution.SPDX.Extra.Internal

import-dirs:          /usr/lib/ghc-8.10.5/site-local/spdx-1.0.0.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/spdx-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/spdx-1.0.0.2
hs-libraries:         HSspdx-1.0.0.2-COGq47VGoHLGd8VVqyuhi
depends:
    Cabal-3.2.1.0 base-4.14.2.0 containers-0.6.4.1 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-spdx/html/spdx.haddock
haddock-html:         /usr/share/doc/haskell-spdx/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

